#!/bin/sh

## play music with mplayer ##
# fzfmp.sh by @root_informatica.

# music dir.
MDIR="$HOME/Música/"
# playlist path.
PLIST="/tmp/playlist"
# make a simple menu.


usage() {
    cat<<EOF
usage:
musicplayer.sh [ albun, song, delete, play, quit ]
album) add albums to the playlist.
song) add individual song/s to the playlist.
delete) delete playlist.
play) play it.
quit) exit.
use < and > for move backward and forwards in the playlist.
EOF
}

# add albums
album() {
    for album in $(find $MDIR -type d | fzfmenu.sh); do
	find $album -maxdepth 1 -type f |
	    grep -E ".mp3|.opus|.flac|.webm|.wav" >> $PLIST
    done
}

# add individual songs
song() {
    find $MDIR -type f |
            grep -E ".mp3|.opus|.flac|.webm|.wav" |
            fzfmenu.sh >> $PLIST
}

# delete playlist
delete() {
    if [ -f $PLIST ]; then
	rm $PLIST
    fi
}

# play it
play() {
    mpv --no-video --playlist=$PLIST
}

error() {
    printf '%s\n' "WRONG ENTRY!"
    sleep 2
}

while true; do
    MENU=$(echo "album\nsong\ndelete\nplay\nview\nquit\nhelp" |
	       fzf --no-sort -m --preview="cat $PLIST | cut -d '/' -f6-7")
    case $MENU in
	album)
	    album
	    ;;
	song)
	    song
	    ;;
	play)
	    play
	    ;;
	delete)
	    delete
	    ;;
	quit)
	    break
	    ;;
	help)
	    usage
	    break
	    ;;
	*)
	    error
	    ;;
    esac
done
